<template>
  <a-card
    :bordered='false'
    :class="'cust-erp-sub-tab'"
  >
    <!-- 查询区域 -->
    <div class='table-page-search-wrapper'>
      <a-form
        layout='inline'
        @keyup.enter.native='searchQuery'
      >
        <a-row :gutter='24'>
        </a-row>
      </a-form>
    </div>
    <div>
      <a-table
        ref='table'
        size='middle'
        bordered
        rowKey='id'
        :scroll="{ x: 'calc(1500px + 40%)', y: 900 }"
        :columns='columns'
        :dataSource='dataSource'
        :pagination='ipagination'
        :loading='loading'
        @change='handleTableChange'

      >
      </a-table>
    </div>


  </a-card>
</template>

<script>
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { getAction } from '@/api/manage'

export default {
  name: 'EquipmentChangeDetail',
  mixins: [JeecgListMixin],
  components: {},
  props: {
    equipmentChangeId: {
      type: String,
      default: '',
      required: false
    }
  },
  watch: {
    equipmentChangeId: {
      immediate: true,
      handler(val) {
        if (!this.equipmentChangeId) {
          this.clearList()
        } else {
          this.queryParam['equipmentChangeId'] = val
          this.queryParam['delFlag'] = 0
          this.loadData(1)
        }
      }
    }
  },
  data() {
    return {
      // disableMixinCreated: true,
      // originTargetKeys: [],
      // 表头
      disableMixinCreated: true,
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 50,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {

          title: '统一编码',
          align: 'center',
          dataIndex: 'equipmentNum',
          width: 170,
        },
        {
          title: '设备名称',
          align: 'center',
          dataIndex: 'equipmentName',
          width: 170,

        },
        {
          title: '型号',
          align: 'center',
          dataIndex: 'specification',
          width: 170,

        },
        {
          title: '规格',
          align: 'center',
          dataIndex: 'model',
          width: 170,
        },
        {
          title: '变动类型',
          align: 'center',
          width: 170,
          dataIndex: 'changeTypeName'

        },
        {
          title: '变动原因',
          align: 'center',
          width: 170,
          dataIndex: 'changeReason'

        },
        {
          title: '变动前管理部门',
          align: 'center',
          width: 170,
          dataIndex: 'beforeDepartName'
        },
        {
          title: '变动后管理部门',
          align: 'center',
          width: 170,
          dataIndex: 'afterDepartName'
        },
        {
          title: '变动前管理人',
          align: 'center',
          width: 170,
          dataIndex: 'beforeManagerName'
        },
        {
          title: '变动后管理人',
          align: 'center',
          width: 170,
          dataIndex: 'afterManagerName'
        },
        {
          title: '变动前使用部门',
          align: 'center',
          width: 170,
          dataIndex: 'beforeUsageDepartName'

        },
        {
          title: '变动后使用部门',
          align: 'center',
          width: 170,
          dataIndex: 'afterUsageDepartName'

        },
        {
          title: '变动前责任班组',
          align: 'center',
          width: 170,
          dataIndex: 'beforeTeamId'

        },

        {
          title: '变动后责任班组',
          align: 'center',
          width: 170,
          dataIndex: 'afterTeamId'

        },
        {
          title: '变动前责任人',
          align: 'center',
          width: 170,
          dataIndex: 'beforeFunctionaryName'

        },
        {
          title: '变动后责任人',
          align: 'center',
          width: 170,
          dataIndex: 'afterFunctionaryName'

        },
        {
          title: '变动前位置',
          align: 'center',
          width: 170,
          dataIndex: 'beforeLocation'

        },
        {
          title: '变动后位置',
          align: 'center',
          width: 170,
          dataIndex: 'afterLocation'

        },
        {
          title: '变动前设备状态',
          align: 'center',
          width: 170,
          dataIndex: 'beforeEquipmentStatus'

        },
        {
          title: '变动后设备状态',
          align: 'center',
          width: 170,
          dataIndex: 'afterEquipmentStatusName'

        },
        {
          title: '变动前技术状态',
          align: 'center',
          width: 170,
          dataIndex: 'beforeTechnologyStatus'

        },  {
          title: '变动后技术状态',
          align: 'center',
          width: 170,
          dataIndex: 'afterTechnologyStatusName'

        }


      ],
      url: {
        list: '/eam/equipmentChangeDetail/getEquipmentChangeDetailList'
      }
    }
  },
  created() {
  },
  computed: {},
  methods: {
    clearList() {
      this.dataSource = []
      this.selectedRowKeys = []
      this.ipagination.current = 1
    },
    loadData(arg) {
      if (!this.url.list) {
        this.$message.error('请设置url.list属性!')
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1
      }
      var params = this.getQueryParams()//查询条件
      this.loading = true
      // this.originTargetKeys = [];
      getAction(this.url.list, params).then((res) => {
        if (res.success) {

          this.dataSource = res.result.records || res.result
          if (res.result.total) {
            this.ipagination.total = res.result.total
          } else {
            this.ipagination.total = 0
          }
          //update-end---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
        } else {
          this.$message.warning(res.message)
        }
      }).finally(() => {
        this.loading = false
      })
    }


  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>
